全国公共资源交易平台

#### 合肥市第四十二中悦·书房LED彩色透明电子屏采购项目中标（成交）公告

发布时间：2020-04-22 21:06信息来源：安徽合肥公共资源交易中心电子交易系统原文链接地址

中标公示
合肥市第四十二中悦·书房LED彩色透明电子屏采购项目中标（成交）公告
一、项目相关情况
项目名称：合肥市第四十二中悦·书房LED彩色透明电子屏采购项目
项目编号：2020ALLHJ00045
招标（采购）方式：竞争性谈判
招标（采购）公告发布日期：2020年04月04日
开标（采购）日期：2020年04月15日
中标公示
中标供应商名称：合肥金色桥广告装饰有限公司
中标供应商联系地址：合肥市亳州路240号3幢102室
中标(成交)金额：人民币 壹拾贰万肆仟元整（￥124000.00元）
中标供应商资料公示:点此浏览企业信息 主要中标或者成交标的的名称、规格型号、数量、单价、服务要求：
评审委员会名单：丁俊锋,冯凯,王月姣 招标（采购）人名称：合肥庐阳大数据产业招商运营有限责任公司
联系人：王月姣
联系方式：0551-62646943
招标（采购）代理机构名称：庐阳合信公共资源交易项目管理有限公司
地址：合肥合肥市庐阳区濉溪路335号（蓝钻尚界）B座4楼
项目负责人：王山远 联系电话：
公告期限：2020年04月15日至2020年04月16日
若供应商对上述结果有异议，可在中标（成交）公告发布之日起七个工作日内以书面形式在工作时间（周一至周五，上午8:00-11:30，下午14:30-17:30，节假日休息）向庐阳区公共资源交易中心提出质疑（异议），质疑材料递交地址：合肥合肥市庐阳区濉溪路335号（蓝钻尚界）B座4楼，联系电话：0551-65699716。
若供应商对质疑处理意见有异议，可在规定时间内以书面形式向合肥市庐阳区财政局提出投诉，联系人：金烨，联系电话：0551-65699707【采购人为合肥行政区域以外单位的项目：向采购人所在地财政部门（公共资源交易监督管理部门）提出投诉】。
二 、质疑提起的条件及不予受理的情形
根据《中华人民共和国政府采购法》、《中华人民共和国政府采购法实施条例》、《安徽省政府采购供应商质疑处理办法》等法律法规，现将质疑提起的条件及不予受理的情形告知如下：
（一）质疑应以书面形式实名提出，书面质疑材料应当包括以下内容：
1、质疑人的名称、地址、邮编、联系人及联系电话；
2、质疑项目的名称、编号、包别号（如有）；
3、被质疑人名称；
4、具体的质疑事项、基本事实及必要的证明材料；
5、明确的请求及主张；
6、必要的法律依据；
7、提起质疑的日期。
质疑人为自然人的，应当由本人签字；质疑人为法人或者其他组织的，应当由法定代表人、主要负责人，或者其授权代表签字或者盖章，并加盖公章。
（二）有下列情形之一的，不予受理：
1、提起质疑的主体不是参与该政府采购项目活动的供应商；
2、提起质疑的时间超过规定时限的；
3、质疑材料不完整的；
4、质疑事项含有主观猜测等内容且未提供有效线索、难以查证的；
5、对其他供应商的投标文件详细内容质疑，无法提供合法来源渠道的；
6、质疑事项已进入投诉处理、行政复议或行政诉讼程序的。
三、其他
（一）、中标(成交)通知书发出情况：
合肥市第四十二中悦·书房LED彩色透明电子屏采购项目中标通知书已发出，请中标（成交）供应商委派专人凭介绍信或公司授权书（须携带身份证）到庐阳合信公共资源交易项目管理有限公司领取中标（成交）通知书。
特此公告。

庐阳合信公共资源交易项目管理有限公司

2020年04月15日